"use strict";
// Copyright (c) Alexey Strokach
// Distributed under the terms of the Modified BSD License.
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const base_1 = require("@jupyter-widgets/base");
const MSA = __importStar(require("msa"));
require("../css/msa.css");
require("../css/widget.css");
const version_1 = require("./version");
class MSAModel extends base_1.DOMWidgetModel {
    defaults() {
        return Object.assign({}, super.defaults(), { _model_name: MSAModel.model_name, _model_module: MSAModel.model_module, _model_module_version: MSAModel.model_module_version, _view_name: MSAModel.view_name, _view_module: MSAModel.view_module, _view_module_version: MSAModel.view_module_version });
    }
}
MSAModel.serializers = Object.assign({}, base_1.DOMWidgetModel.serializers
// Add any extra serializers here
);
MSAModel.model_name = "MSAModel";
MSAModel.model_module = version_1.MODULE_NAME;
MSAModel.model_module_version = version_1.MODULE_VERSION;
MSAModel.view_name = "MSAView"; // Set to null if no view
MSAModel.view_module = version_1.MODULE_NAME; // Set to null if no view
MSAModel.view_module_version = version_1.MODULE_VERSION;
exports.MSAModel = MSAModel;
class MSAView extends base_1.DOMWidgetView {
    render() {
        this.el.classList.add("jp-RenderedMSA");
        let msaDiv = document.createElement("div");
        this.msa = new MSA.msa({
            el: msaDiv,
            vis: {
                labelId: false,
                sequences: true,
                markers: true,
                metacell: false,
                conserv: false,
                overviewbox: false,
                seqlogo: true,
                gapHeader: false,
                leftHeader: true
            }
        });
        this.el.appendChild(msaDiv);
        this.model.on("change:value", this.value_changed.bind(this), this);
        // this.model.on("msg:custom", this.on_msg, this);
    }
    value_changed() {
        let seqs = this.model.get("value");
        // console.log("seqs:", seqs);
        // let seqs = MSA.io.fasta.parse(data);
        // if (this.msa.seqs.length > 100) {
        //   this.msa.seqs.pop();
        // }
        this.msa.seqs.reset(seqs);
        this.msa.render();
    }
    on_msg(msg) {
        console.log("msg.type", msg.type);
        console.log("msg.target", msg.target);
        console.log("msg.methodName", msg.methodName);
        console.log("msg.args", msg.args);
        console.log("msg.kwargs", msg.kwargs);
        console.assert(msg.type === "call_method");
        let new_args = msg.args.slice();
        new_args.push(msg.kwargs);
        let target;
        switch (msg.target) {
            case "MSA":
                target = this.msa;
            case "SEQS":
                target = this.msa.seqs;
            // *reset*
            // this.msa.seqs.reset(seqs);
            // *add*
            default:
                console.warn("There is no method for " + msg.target);
                break;
        }
        let func = target[msg.methodName];
        func.apply(target, new_args);
        // this.msa.render();
    }
}
exports.MSAView = MSAView;
//# sourceMappingURL=widget_msa.js.map